@@ -10,6 +10,21 @@
 from rest_framework.response import Response
 
 
+class DetailResponse(Response):
+    """
+    不包含分页信息的接口返回,主要用于单条数据查询
+    (1)默认code返回2000, 不支持指定其他返回码
+    """
+
+    def __init__(self, data=None, msg='success', status=None, template_name=None, headers=None, exception=False,
+                 content_type=None,):
+        std_data = {
+            "code": 2000,
+            "data": data,
+            "msg": msg
+        }
+        super().__init__(std_data, status, template_name, headers, exception, content_type)
+
 class SuccessResponse(Response):
     """
     标准响应成功的返回, SuccessResponse(data)或者SuccessResponse(data=data)
